<?php

/**
 * @file
 * Create a block as a hierarchical menu tree for each vocabulary. 
 */

function taxonomy_context_admin_settings() {
  // We need the CSS here.
  drupal_add_css(drupal_get_path('module', 'taxonomy_context') . '/taxonomy_context.css');

  $form = array();
  $endis = array(t('No'), t('Yes'));

  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
    '#collapsible' => TRUE,
    );

  $form['general']['taxonomy_context_use_style'] = array(
    '#type' => 'radios',
    '#title' => t('Use style for term and subterm display'),
    '#default_value' => variable_get('taxonomy_context_use_style', 0),
    '#options' => $endis,
    '#description' => t('Include the module\'s style declaration (CSS) to display taxonomy info. Disable this option if you wish to do this instead through editing your theme\'s .css files.'),
    );

  $form['general']['taxonomy_context_show_term'] = array(
    '#type' => 'radios',
    '#title' => t('Show term info'),
    '#default_value' => variable_get('taxonomy_context_show_term', 1),
    '#options' => $endis,
    '#description' => t('Show additional information about current term (from description).'),
    );

  $form['general']['taxonomy_context_show_subterms'] = array(
    '#type' => 'radios',
    '#title' => t('Show subterm info'),
    '#default_value' => variable_get('taxonomy_context_show_subterms', 1),
    '#options' => $endis,
    '#description' => t('Show listings of subterms (sub-categories) for current term.'),
    );

  $form['general']['taxonomy_context_subterm_indent'] = array(
    '#type' => 'textfield',
    '#title' => t('Subterm indent character'),
    '#default_value' => variable_get('taxonomy_context_subterm_indent', '&mdash;'),
    '#size' => 32,
    '#description' => t('Subterms will be indented to show hierarchy; this is what is used to show the indentation. It will be repeated for each level of depth.'),
    );

  $form['general']['taxonomy_context_suppress_current'] = array(
    '#type' => 'radios',
    '#title' => t('Suppress current term on taxonomy/term/xxx page'),
    '#default_value' => variable_get('taxonomy_context_suppress_current', 0),
    '#options' => $endis,
    '#description' => t('Use this option to remove the current term from nodes shown on a taxonomy/term/xxx page. "No" is standard Drupal behavior; "yes" will remove the current term from each node selected.'),
    );

  $form['overview'] = array(
    '#type' => 'fieldset',
    '#title' => t('Overview pages'),
    '#collapsible' => TRUE,
    );

  $form['overview']['taxonomy_context_max_depth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum term depth for overview'),
    '#default_value' => variable_get('taxonomy_context_max_depth', 1),
    '#size' => 8,
    '#description' => t('This is how deep in the hierarchy to show terms on the overview ("menu") page. A value of 1 shows only the highest level.'),
    );

  $form['overview']['taxonomy_context_count_nodes'] = array(
    '#type' => 'radios',
    '#title' => t('Show node count on overview page'),
    '#default_value' => variable_get('taxonomy_context_count_nodes', 0),
    '#options' => $endis,
    '#description' => t('Show the number of nodes tagged with each term. For example: term-name (nnn)'),
    );

  $form['overview']['taxonomy_context_show_related'] = array(
    '#type' => 'radios',
    '#title' => t('Show related terms'),
    '#default_value' => variable_get('taxonomy_context_show_related', 0),
    '#options' => $endis,
    '#description' => t('If a term has related terms, show them as a cross-reference.'),
    );

  $form['overview']['taxonomy_context_show_synonyms'] = array(
    '#type' => 'radios',
    '#title' => t('Show synonyms'),
    '#default_value' => variable_get('taxonomy_context_show_synonyms', 0),
    '#options' => $endis,
    '#description' => t('If a term has similar terms (synonyms), show them as a cross-reference.'),
    );

  $num_titles = variable_get('taxonomy_context_show_titles', 0);
  $order = variable_get('taxonomy_context_show_order', 'n.title');

  $form['titles'] = array(
    '#type' => 'fieldset',
    '#title' => t('Node title display'),
    '#collapsible' => TRUE,
    );

  $form['titles']['taxonomy_context_show_titles'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum titles to show for each term'),
    '#default_value' => variable_get('taxonomy_context_show_titles', 0),
    '#size' => 8,
    '#description' => t('This is how many node titles to show for each term on the overview ("menu") page. A value of 0 means don\'t show any.'),
    );

  $form['titles']['taxonomy_context_show_order'] = array(
    '#type' => 'radios',
    '#title' => t('Title order'),
    '#default_value' => variable_get('taxonomy_context_show_order', 'n.title'),
    '#options' => array(
      'n.title' => t('by title (ascending)'),
      'n.sticky DESC, n.created DESC' => t('by standard Drupal order (sticky, most recent)'),
      ),
    '#description' => t('In what order do you wish to show the titles? This may also affect which titles are shown if there are more than the limit above.'),
    );

  $form['blocks'] = array(
    '#type' => 'fieldset',
    '#title' => t('Block settings'),
    '#collapsible' => TRUE,
    );

  $form['blocks']['taxonomy_context_block_display'] = array(
    '#type' => 'radios',
    '#title' => t('Show block items'),
    '#default_value' => variable_get('taxonomy_context_block_display', TAXONOMY_CONTEXT_BLOCK_DISPLAY_COLLAPSED),
    '#options' => array(t('Collapsed'), t('Expanded')),
    '#description' => t('Do you want items on the menu expanded or collapsed by default?'),
    );

  $form['blocks']['taxonomy_context_node_block'] = array(
    '#type' => 'radios',
    '#title' => t('Show nodes in block'),
    '#default_value' => variable_get('taxonomy_context_node_block', TAXONOMY_CONTEXT_NODE_BLOCK_NONE),
    '#options' => array(t('None'), t('Sticky'), t('Promoted'), t('All')),
    '#description' => t('What nodes do you wish to display in taxonomy blocks?'),
    );

  $form['blocks']['taxonomy_context_block_count_nodes'] = array(
    '#type' => 'radios',
    '#title' => t('Show node counts in block items'),
    '#default_value' => variable_get('taxonomy_context_block_count_nodes', TAXONOMY_CONTEXT_BLOCK_COUNT_NODES_FALSE),
    '#options' => $endis,
    '#description' => t('Show node counts in block after items. Example: term (nnn)'),
    );

  return system_settings_form($form);
}
