<?php
// $Id $

/**
 * @file
 * Theme functions for Taxonomy Context. 
 */

/**
 * Display related terms.
 */
function theme_taxonomy_context_related($term) {
  $output = '';
  if ($term->related) {
    $output .= '<div class="taxonomy-context-related"><span>'
      . t('Related') . '</span>: ' 
      . check_plain(implode(', ', array_keys($term->related)))
      . '</div>';
  }
  return $output;
}

/**
 * Display synonyms for terms.
 */
function theme_taxonomy_context_synonyms($term) {
  $output = '';
  if ($term->synonyms) {
    $output .= '<div class="taxonomy-context-synonyms"><span>'
      . t('Synonyms') . '</span>: ' 
      . check_plain(implode(', ', $term->synonyms))
      . '</div>';
  }
  return $output;
}

/**
 * Display subterms.
 */
function theme_taxonomy_context_subterms($terms) {
  $output = '';
  if (count($terms)) {
    foreach ($terms as $term) {
      taxonomy_context_load('term', $term);
      $term->subterm = TRUE;
      $term->teaser = isset($term->description) ? node_teaser($term->description, isset($term->format) ? $term->format : NULL) : '';
      $term = taxonomy_context_prepare($term, TRUE);
      $term->links = module_invoke_all('link', 'term', $term);
      $output .= theme('taxonomy_context_term', $term);
    }
  }
  return $output;
}

/**
 * Theme a term output.
 */
function theme_taxonomy_context_term($term) {
  $indent_char = variable_get('taxonomy_context_subterm_indent', '&mdash;');
  $show_related = variable_get('taxonomy_context_show_related', 0);
  $show_synonyms = variable_get('taxonomy_context_show_synonyms', 0);
  $type = $term->subterm ? 'subterm' : 'term';
  $output = "<div class=\"$type-container\">\n  <div class=\"$type\">\n";
  $indent = str_repeat($indent_char, $term->depth) .' ';
  $img = taxonomy_image_display($term->tid, NULL, NULL, array('wrapper' => TRUE));
  $name = tt("taxonomy:term:$term->tid:name", $term->name, NULL, TRUE);
  $level = 2 + $term->subterm;
  $output .= '<h' . $level . ' class="title">'
    . $img
    . $indent
    . l($name, taxonomy_term_path($term))
    . "</h$level>";
  $term->description = tt("taxonomy:term:$term->tid:description", $term->description, NULL, FALSE);
  $output .= '<div class="' . ($term->teaser ? 'teaser' : 'description') .'">' . $term->description . '</div>';

  if ($show_related) {
    $output .= theme('taxonomy_context_related', $term);    
  }

  if ($show_synonyms) {
    $output .= theme('taxonomy_context_synonyms', $term);    
  }

  if ($term->links) {
    $output .= '<div class="links">'. theme('links', $term->links) . "</div>\n";
  }

  if ($node_list = _taxonomy_context_get_titles($term->tid)) {
    $output .= theme('item_list', $node_list);
  }  
  $output .= "  </div>\n";
  $output .= "</div>\n";
  return $output;
}

/**
 * Theme a vocabulary output.
 */
function theme_taxonomy_context_vocabulary($vocabulary) {
  $output .= "<div class=\"vocabulary-container\">\n";
  $output .= "  <div class=\"vocabulary\">\n";
  $output .= '   <div class="description">' . $vocabulary->description . "</div>\n";
  if ($vocabulary->links) {
    $output .= '   <div class="links">'. theme('links', $vocabulary->links) . "</div>\n";
  }
  if ($vocabulary->terms && is_array($vocabulary->terms)) {
    foreach ($vocabulary->terms as $term) {
      $term->subterm = TRUE;
      $output .= theme('taxonomy_context_term', $term);
    }
  }
  $output .= "  </div>\n";
  $output .= "</div>\n";

  return $output;
}

/**
 * Theme a list of vocabulary and term links.
 */
function theme_taxonomy_context_vocabulary_list($vocabulary) {
  $indent_char = variable_get('taxonomy_context_subterm_indent', '&mdash;');
  $output = '<div class="vocabulary-list-'. $vocabulary->vid .'">';
  $output .= '<h3 class="title">' . l($vocabulary->name, "taxonomy/vocabulary/$vocabulary->vid") . "</h3>\n";
  $items = array();
  foreach ($vocabulary->terms as $term) {
    // Indent child terms.
    $indent = str_repeat($indent_char, $term->depth) .' ';
    $node_list = array();
    $indent = str_repeat($indent_char, $term->depth) .' ';
    $img = taxonomy_image_display($term->tid, NULL, NULL, array('wrapper' => TRUE));
    $name = tt("taxonomy:term:$term->tid:name", $term->name, NULL, TRUE);
    $items[] = array(
      'data' => $img . $indent . l($name, taxonomy_term_path($term)),
      'children' => _taxonomy_context_get_titles($term->tid),
      'class' => 'vocabulary-list depth-'. $term->depth,
      );
  }
  $output .= theme('item_list', $items);
  return $output .'</div>';
}
